0.9.9 API documentation: matrix_float2x3.hpp File Reference

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

Typedefs
matrix_float2x3.hpp File Reference

Core features More...

Go to the source code of this file.

## Typedefs
typedef mat< 2, 3, float, defaultp > | mat2x3
| 2 columns of 3 components matrix of single-precision floating-point numbers. More...

## Detailed Description

Core features

Definition in file matrix_float2x3.hpp.